@@ -1,6 +1,8 @@
+import base64
 import logging
-import platform
+import mimetypes
 import os
+import platform
 import shutil
 import subprocess
 from functools import wraps
@@ -42,7 +44,7 @@ class Bridge:
         on_top: bool = False,
     ):
         self.logger = logging.getLogger(__name__)
-        self.elements: Elements = elements
+        self.elements: Elements = self._parse_elements(elements)
 
         self.auto_height = auto_height
         self.max_height = max_height
@@ -55,6 +57,31 @@ class Bridge:
         # Injected after instantiation
         self.window: Optional[webview.Window] = None
 
+    def _parse_elements(self, elements: Elements) -> Elements:
+        for element in elements:
+            if element["type"] == "image":
+                value = element["value"]
+                element["value"] = self._load_image(value)
+
+        return elements
+
+    def _load_image(self, url_or_path: str) -> str:
+        try:
+            is_file = Path(url_or_path).is_file()
+        except OSError:
+            is_file = False
+
+        if not is_file:
+            # Assume image is a remote URL, which can be used as-is
+            return url_or_path
+
+        # Serve local files as data-uri, since the webview component
+        # most likely can't serve the file directly
+        mime, _ = mimetypes.guess_type(url_or_path)
+        with open(url_or_path, "rb") as fd:
+            data = base64.b64encode(fd.read()).decode()
+            return f"data:{mime};base64,{data}"
+
     def _find_by_name(self, name: str) -> Element:
         for element in self.elements:
             if element.get("name") == name:
